@@ -4,7 +4,7 @@ use strict;
 use Any::Moose;
 use Web::API::Mapper::RuleSet;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 has route => ( is => 'rw' );
 
@@ -131,6 +131,55 @@ API to web frameworks.
     $m->post->mount( '/foo' , [ '/subpath/to' => sub {  ....  } ]);
     $m->mount( '/fb' => {  post => [  ... ] , get => [  ... ] }  )->mount( ... );
 
+To generate API routing table automatically, see test file F<t/auto-router.t>:
+
+
+#!/usr/bin/env perl
+    use Test::More tests => 6;
+    use Web::API::Mapper;
+
+    my $api = Test::API->new;
+    my $routes = Web::API::Mapper->auto_route( $api , { prefix => 'foo' } );
+
+    ok( $routes->{get} );
+    ok( $routes->{post} );
+    ok( $routes->{any} );
+
+    # The $routes will be:
+    # {
+    #     post => [ ],
+    #     get => [ ],
+    #     any => [
+    #         '/get/id' => sub { DUMMY }
+    #         '/get/id' => sub { DUMMY }
+    #     ]
+    # }
+
+    my $m = Web::API::Mapper->new( "/foo" => $routes );
+    ok( $m );
+    my $ret = $m->dispatch( '/foo/get/id' , { data => 'John' } );
+
+    is_deeply( $ret->{args} , { data => 'John' } );
+    is( ref($ret->{self}) , 'Test::API' );
+
+    package Test::API;
+
+    sub new { bless {} , shift; }
+
+    sub foo_get_id {
+        my ($self,$args) = @_;
+        return {  
+            self => $self,
+            args => $args,
+        };
+    }
+
+    sub foo_set_id {
+
+    }
+
+    1;
+
 
 =head1 DESCRIPTION
 
